@@ -27,4 +27,6 @@ def create(arguments: Dict[str, Any]) -> Any:
         credentials = args_copy.pop("credentials")
     if "application_id" in args_copy:
         application_id = args_copy.pop("application_id")
-    return creator_func(args_copy, credentials=credentials, application_id=application_id)
+    return creator_func(
+        args_copy, credentials=credentials, application_id=application_id
+    )
