@@ -5,10 +5,11 @@ from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsCloudFormation(BaseProvider):
-    def __init__(self,
-                 resource: Dict,
-                 **kwargs,
-                 ) -> None:
+    def __init__(
+        self,
+        resource: Dict,
+        **kwargs,
+    ) -> None:
         """
         Constructor method
         """
@@ -19,20 +20,22 @@ class AwsCloudFormation(BaseProvider):
         """Get service inventory resource"""
         response = self.conn.describe_stacks()
 
-        return [{**item, "type": "cloudformation"} for item in response.get('Stacks', [])]
+        return [
+            {**item, "type": "cloudformation"} for item in response.get("Stacks", [])
+        ]
 
     def get_resources(self):
         """
         Fetches CloudFormation details.
         """
 
-        stack_policy_body = self.conn.get_stack_policy(StackName=self.resource.get('StackName')).get('StackPolicyBody')
-        stacks = self.conn.describe_stacks(StackName=self.resource.get('StackName')).get('Stacks')
-        return {
-            **self.resource,
-            "StackPolicyBody": stack_policy_body,
-            "Stacks": stacks
-        }
+        stack_policy_body = self.conn.get_stack_policy(
+            StackName=self.resource.get("StackName")
+        ).get("StackPolicyBody")
+        stacks = self.conn.describe_stacks(
+            StackName=self.resource.get("StackName")
+        ).get("Stacks")
+        return {**self.resource, "StackPolicyBody": stack_policy_body, "Stacks": stacks}
 
 
 def register() -> Any:
