@@ -67,7 +67,7 @@ class AwsCluster(BaseProvider):
         cluster_host,
     ):
         """Get cluster client"""
-        work_session = self.session._session  #pylint: disable=W0212
+        work_session = self.session._session  # pylint: disable=W0212
         client_factory = STSClientFactory(work_session)
 
         def get_expiration_time():
@@ -291,7 +291,9 @@ class AwsCluster(BaseProvider):
                 try:
                     self.add_cluster_objects_from_cloudwatch(cluster_details)
                 except Exception as cluster_cloud_ex:
-                    logger.error(f"Error add cluster objects from cloud watch {cluster_cloud_ex}")
+                    logger.error(
+                        f"Error add cluster objects from cloud watch {cluster_cloud_ex}"
+                    )
 
         if self.cluster_names and len(self.cluster_names) == 1:
             name = self.cluster_names[0]
