@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
-from matos_aws_provider.lib.base_provider import BaseProvider
-from matos_aws_provider.lib.log import get_logger
+import logging
 import botocore
+from matos_aws_provider.lib import factory
+from matos_aws_provider.lib.base_provider import BaseProvider
 
-logger = get_logger()
+logger = logging.getLogger(__name__)
 
 
 class AwsDax(BaseProvider):
+    """Aws dax plugin"""
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct cluster service
@@ -42,4 +43,5 @@ class AwsDax(BaseProvider):
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("dax", AwsDax)
