@@ -6,6 +6,7 @@ from matos_aws_provider.lib.base_provider import BaseProvider
 
 class AwsGlue(BaseProvider):
     """Aws glue plugin"""
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct Glue service
@@ -44,7 +45,8 @@ class AwsGlue(BaseProvider):
         if (
             resource["DataCatalogueEncryptionSettings"]
             .get("EncryptionAtRest", {})
-            .get("CatalogEncryptionMode") != "DISABLED"
+            .get("CatalogEncryptionMode")
+            != "DISABLED"
         ):
             resource["DataCatalogueEncryptionSettings"][
                 "KeyDetails"
