@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 class AwsInstance(BaseProvider):
     """AWS instance plugin"""
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct instance service
@@ -116,7 +117,10 @@ class AwsInstance(BaseProvider):
                         instance_details.get("InstanceId"), "Association"
                     )
 
-                if self.instance_ids and instance_details.get("InstanceId") in self.instance_ids:
+                if (
+                    self.instance_ids
+                    and instance_details.get("InstanceId") in self.instance_ids
+                ):
                     return instance_details
             return instances
         return []
