@@ -5,10 +5,11 @@ from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsRoute53(BaseProvider):
-    def __init__(self,
-                 resource: Dict,
-                 **kwargs,
-                 ) -> None:
+    def __init__(
+        self,
+        resource: Dict,
+        **kwargs,
+    ) -> None:
         """
         Constructor method
         """
@@ -18,18 +19,16 @@ class AwsRoute53(BaseProvider):
     def get_inventory(self):
         """Get service inventory resource"""
         response = self.conn.list_hosted_zones()
-        return [{**item, "type": "route53"} for item in response.get('HostedZones', [])]
+        return [{**item, "type": "route53"} for item in response.get("HostedZones", [])]
 
     def get_resources(self):
         """
         Fetches resource details.
         """
-        query_logging_configs = self.conn.list_query_logging_configs(HostedZoneId=self.resource.get('Id')).get(
-            'QueryLoggingConfigs')
-        resource = {
-            **self.resource,
-            "QueryLoggingConfig": query_logging_configs
-        }
+        query_logging_configs = self.conn.list_query_logging_configs(
+            HostedZoneId=self.resource.get("Id")
+        ).get("QueryLoggingConfigs")
+        resource = {**self.resource, "QueryLoggingConfig": query_logging_configs}
         return resource
 
 
