@@ -5,10 +5,11 @@ from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsRoute53Domain(BaseProvider):
-    def __init__(self,
-                 resource: Dict,
-                 **kwargs,
-                 ) -> None:
+    def __init__(
+        self,
+        resource: Dict,
+        **kwargs,
+    ) -> None:
         """
         Constructor method
         """
@@ -18,17 +19,18 @@ class AwsRoute53Domain(BaseProvider):
     def get_inventory(self):
         """Get service inventory resource"""
         response = self.conn.list_domains()
-        return [{**item, "type": "route53domains"} for item in response.get('Domains', [])]
+        return [
+            {**item, "type": "route53domains"} for item in response.get("Domains", [])
+        ]
 
     def get_resources(self):
         """
         Fetches resource details.
         """
-        details = self.conn.get_domain_detail(DomainName=self.resource.get('DomainName'))
-        resource = {
-            **self.resource,
-            **details
-        }
+        details = self.conn.get_domain_detail(
+            DomainName=self.resource.get("DomainName")
+        )
+        resource = {**self.resource, **details}
 
         return resource
 
