@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 class AwsStorage(BaseProvider):
     """AWS storage"""
+
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct cloudtrail service
@@ -166,7 +167,7 @@ class AwsStorage(BaseProvider):
                 )
 
         except Exception as ex:
-            logger.error("%s metric configuration: %s", self.bucket['name'], ex)
+            logger.error("%s metric configuration: %s", self.bucket["name"], ex)
             return []
 
         return metrics
@@ -197,7 +198,7 @@ class AwsStorage(BaseProvider):
                 )
 
         except Exception as ex:
-            logger.warning("%s inventory configuration: %s", self.bucket['name'], ex)
+            logger.warning("%s inventory configuration: %s", self.bucket["name"], ex)
             return []
 
         return inventories
@@ -230,7 +231,9 @@ class AwsStorage(BaseProvider):
                 )
 
         except Exception as ex:
-            logger.error(f"{self.bucket['name']} intelligent tiering configuration: {ex}")
+            logger.error(
+                f"{self.bucket['name']} intelligent tiering configuration: {ex}"
+            )
             return []
 
         return tiering
